==> kospi_kosdaq_stock_server-0.1.1-py3-none-any.whl: README.md <==
# kospi-kosdaq-stock-server

[![PyPI version](https://badge.fury.io/py/kospi-kosdaq-stock-server.svg)](https://badge.fury.io/py/kospi-kosdaq-stock-server)

An MCP server that provides KOSPI/KOSDAQ stock data.

## Features

- Lookup KOSPI/KOSDAQ ticker symbols and names
- Retrieve OHLCV data for a specific stock
- Retrieve market capitalization data for a specific stock
- Retrieve fundamental data (PER/PBR/Dividend Yield) for a specific stock
- Retrieve trading volume by investor type for a specific stock

## Available Tools

- `load_all_tickers` - Loads all ticker symbols and names for KOSPI and KOSDAQ into memory.
    - No arguments.

- `get_stock_ohlcv` - Retrieves OHLCV (Open/High/Low/Close/Volume) data for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol
    - `adjusted` (boolean, optional): Whether to use adjusted prices (True: adjusted, False: unadjusted). Defaults to True.

- `get_stock_market_cap` - Retrieves market capitalization data for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

- `get_stock_fundamental` - Retrieves fundamental data (PER/PBR/Dividend Yield) for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

- `get_stock_trading_volume` - Retrieves trading volume by investor type for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

## Installation

```bash
pip install kospi-kosdaq-stock-server
```

## Configuration for Claude.app

After installing the package, you need to configure the MCP server in your `claude_desktop_config.json` file.

1.  **Locate the configuration file:**
    *   On macOS, the file is typically located at:
        `/Users/aerok/Library/Application Support/Claude/claude_desktop_config.json`

2.  **Add the server configuration:**
    Open the `claude_desktop_config.json` file and add a new entry to the `mcpServers` object. Use a unique name for the server (e.g., `"kospi-kosdaq"`).

<details>
<summary>Using pip installation</summary>

```json
{
  "mcpServers": {
    "kospi-kosdaq": {
      "command": "python",
      "args": ["-m", "kospi_kosdaq_stock_server"],
      "env": {}
    }
  }
}
```

</details>

<details>
<summary>Using uvx (optional, after PyPI deployment)</summary>

```json
{
    "mcpServers": {
        "kospi-kosdaq": {
            "command": "uvx",
            "args": ["kospi-kosdaq-stock-server"],
            "env": {}
        }
    }
}
```

</details>

*   **`command`**: This is the command to run the server.
    *   If you installed it via `pip`, the command is `python -m kospi_kosdaq_stock_server`.
    *   If you are using `uvx`, the command is simply the package name: `kospi-kosdaq-stock-server`. **Note:** Using `uvx` is recommended after the package is deployed to PyPI.
*   **`args`**: This server doesn't require any command-line arguments, so leave this as an empty array (`[]`).
*   **`env`**: This server doesn't require any environment variables, so you can leave this as an empty object (`{}`).

3.  **Restart the MCP client:** After saving the changes to `claude_desktop_config.json`, restart your MCP client (e.g., Claude) for the changes to take effect.

## License

[MIT License](LICENSE)

==> kospi_kosdaq_stock_server-0.1.2-py3-none-any.whl: README.md <==
# kospi-kosdaq-stock-server

[![PyPI version](https://badge.fury.io/py/kospi-kosdaq-stock-server.svg)](https://badge.fury.io/py/kospi-kosdaq-stock-server)

An MCP server that provides KOSPI/KOSDAQ stock data.

## Features

- Lookup KOSPI/KOSDAQ ticker symbols and names
- Retrieve OHLCV data for a specific stock
- Retrieve market capitalization data for a specific stock
- Retrieve fundamental data (PER/PBR/Dividend Yield) for a specific stock
- Retrieve trading volume by investor type for a specific stock

## Available Tools

- `load_all_tickers` - Loads all ticker symbols and names for KOSPI and KOSDAQ into memory.
    - No arguments.

- `get_stock_ohlcv` - Retrieves OHLCV (Open/High/Low/Close/Volume) data for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol
    - `adjusted` (boolean, optional): Whether to use adjusted prices (True: adjusted, False: unadjusted). Defaults to True.

- `get_stock_market_cap` - Retrieves market capitalization data for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

- `get_stock_fundamental` - Retrieves fundamental data (PER/PBR/Dividend Yield) for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

- `get_stock_trading_volume` - Retrieves trading volume by investor type for a specific stock.
    - `fromdate` (string, required): Start date for retrieval (YYYYMMDD)
    - `todate` (string, required): End date for retrieval (YYYYMMDD)
    - `ticker` (string, required): Stock ticker symbol

## Installation

```bash
pip install kospi-kosdaq-stock-server
```

## Configuration for Claude.app

After installing the package, you need to configure the MCP server in your `claude_desktop_config.json` file.

1.  **Locate the configuration file:**
    *   On macOS, the file is typically located at:
        `/Users/username/Library/Application Support/Claude/claude_desktop_config.json`

2.  **Add the server configuration:**
    Open the `claude_desktop_config.json` file and add a new entry to the `mcpServers` object. Use a unique name for the server (e.g., `"kospi-kosdaq"`).

<details>
<summary>Using pip installation</summary>

```json
{
  "mcpServers": {
    "kospi-kosdaq": {
      "command": "python",
      "args": ["-m", "kospi_kosdaq_stock_server"],
      "env": {}
    }
  }
}
```

</details>

<details>
<summary>Using uvx</summary>

```json
{
    "mcpServers": {
        "kospi-kosdaq": {
            "command": "uvx",
            "args": ["kospi-kosdaq-stock-server"],
            "env": {}
        }
    }
}
```

</details>

*   **`command`**: This is the command to run the server.
    *   If you installed it via `pip`, the command is `python -m kospi_kosdaq_stock_server`.
    *   If you are using `uvx`, the command is simply the package name: `kospi-kosdaq-stock-server`. **Note:** Using `uvx` is recommended after the package is deployed to PyPI.
*   **`args`**: This server doesn't require any command-line arguments, so leave this as an empty array (`[]`).
*   **`env`**: This server doesn't require any environment variables, so you can leave this as an empty object (`{}`).

3.  **Restart the MCP client:** After saving the changes to `claude_desktop_config.json`, restart your MCP client (e.g., Claude) for the changes to take effect.

## License

[MIT License](LICENSE)
